@@ -1,5 +1,5 @@
 /*
-	libmpg123: MPEG Audio Decoder library (version 1.27.2)
+	libmpg123: MPEG Audio Decoder library (version 1.29.0)
 
 	copyright 1995-2015 by the mpg123 project
 	free software under the terms of the LGPL 2.1
@@ -17,7 +17,9 @@
  * This should be incremented at least each time a new symbol is added
  * to the header.
  */
+#ifndef MPG123_API_VERSION
 #define MPG123_API_VERSION 46
+#endif
 
 #ifndef MPG123_EXPORT
 /** Defines needed for MS Visual Studio(tm) DLL builds.
@@ -41,13 +43,6 @@
 #endif
 #endif
 
-/* This is for Visual Studio, so this header works as distributed in the binary downloads */
-#if defined(_MSC_VER) && !defined(MPG123_DEF_SSIZE_T)
-#define MPG123_DEF_SSIZE_T
-#include <stddef.h>
-typedef ptrdiff_t ssize_t;
-#endif
-
 /** Earlier versions of libmpg123 put enums into public API calls,
  * thich is not exactly safe. There are ABI rules, but you can use
  * compiler switches to change the sizes of enums. It is safer not
@@ -76,10 +71,32 @@ typedef ptrdiff_t ssize_t;
 
 #endif
 
-#ifndef MPG123_NO_CONFIGURE /* Enable use of this file without configure. */
+/* You can use this file directly, avoiding the autoconf replacements.
+   Might have to set MPG123_NO_LARGENAME, too, in case you have
+   _FILE_OFFSET_BITS defined where it does not make sense. */
+#ifndef MPG123_NO_CONFIGURE
+
 #include <stdlib.h>
 #include <sys/types.h>
 
+/* A little hack to help MSVC not having ssize_t. */
+#ifdef _MSC_VER
+#include <stddef.h>
+typedef ptrdiff_t mpg123_ssize_t;
+#else
+typedef ssize_t mpg123_ssize_t;
+#endif
+
+/* You can always enforce largefile hackery by setting MPG123_LARGESUFFIX. */
+/* Otherwise, this header disables it if the build system decided so. */
+#if !defined(MPG123_LARGESUFFIX) && 0
+#ifndef MPG123_NO_LARGENAME
+#define MPG123_NO_LARGENAME
+#endif
+#endif
+
+#endif /* MPG123_NO_CONFIGURE */
+
 /* Simplified large file handling.
 	I used to have a check here that prevents building for a library with conflicting large file setup
 	(application that uses 32 bit offsets with library that uses 64 bits).
@@ -136,8 +153,6 @@ typedef ptrdiff_t ssize_t;
 
 #endif /* largefile hackery */
 
-#endif /* MPG123_NO_CONFIGURE */
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -383,7 +398,7 @@ enum mpg123_feature_set
 	,MPG123_FEATURE_EQUALIZER            /**< tunable equalizer */
 	,MPG123_FEATURE_MOREINFO             /**< more info extraction (for frame analyzer) */
 	,MPG123_FEATURE_OUTPUT_FLOAT32      /**< 32 bit float output */
-	,MPG123_FEATURE_OUTPUT_FLOAT64      /**< 64 bit float output (usually never) */
+	,MPG123_FEATURE_OUTPUT_FLOAT64      /**< 64 bit float output (as of now: never!) */
 };
 
 #ifdef MPG123_ENUM_API
@@ -732,7 +747,7 @@ MPG123_EXPORT int mpg123_getformat2( mpg123_handle *mh
  *  will also be decoded without you really noticing. Just the speed could be
  *  wrong if you do not care about sample rate at all.
  *  \param mh handle
- *  \param path filesystem path
+ *  \param path filesystem path (see mpg123_open())
  *  \param channels allowed channel count, either 1 (MPG123_MONO) or
  *    2 (MPG123_STEREO), or bitwise or of them, but then you're halfway back to
  *    calling mpg123_format() again;-)
@@ -745,8 +760,16 @@ MPG123_EXPORT int mpg123_open_fixed(mpg123_handle *mh, const char *path
 /** Open and prepare to decode the specified file by filesystem path.
  *  This does not open HTTP urls; libmpg123 contains no networking code.
  *  If you want to decode internet streams, use mpg123_open_fd() or mpg123_open_feed().
+ *
+ *  The path parameter usually is just a string that is handed to the underlying
+ *  OS routine for opening, treated as a blob of binary data. On platforms
+ *  where encoding needs to be involved, something like _wopen() is called
+ *  underneath and the path argument to libmpg123 is assumed to be encoded in UTF-8.
+ *  So, if you have to ask yourself which encoding is needed, the answer is
+ *  UTF-8, which also fits any sane modern install of Unix-like systems.
+ *
  *  \param mh handle
- *  \param path filesystem path
+ *  \param path filesystem
  *  \return MPG123_OK on success
  */
 MPG123_EXPORT int mpg123_open(mpg123_handle *mh, const char *path);
@@ -1946,7 +1969,7 @@ MPG123_EXPORT size_t mpg123_outblock(mpg123_handle *mh);
  * \return MPG123_OK on success
  */
 MPG123_EXPORT int mpg123_replace_reader( mpg123_handle *mh
-,	ssize_t (*r_read) (int, void *, size_t)
+,	mpg123_ssize_t (*r_read) (int, void *, size_t)
 ,	off_t (*r_lseek)(int, off_t, int)
 );
 
@@ -1965,7 +1988,7 @@ MPG123_EXPORT int mpg123_replace_reader( mpg123_handle *mh
  * \return MPG123_OK on success
  */
 MPG123_EXPORT int mpg123_replace_reader_handle( mpg123_handle *mh
-,	ssize_t (*r_read) (void *, void *, size_t)
+,	mpg123_ssize_t (*r_read) (void *, void *, size_t)
 ,	off_t (*r_lseek)(void *, off_t, int)
 ,	void (*cleanup)(void*) );
 
